L class

Constructors

L()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(dynamic msg, [String? tag]) → void
e(dynamic msg, [String? tag, Object? error, StackTrace? stackTrace]) → void
i(dynamic msg, [String? tag]) → void
json(dynamic json, [String? tag]) → void
long(dynamic msg, [String? tag]) → void
p(dynamic msg) → void
trace([String? msg, String? tag]) → void
v(dynamic msg, [String? tag]) → void
w(dynamic msg, [String? tag]) → void
wtf(dynamic msg, [String? tag]) → void